==> antlr-java-parser-1.0.5-sources.jar: com/github/antlrjavaparser/adapter/EnumBodyDeclarationsContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.body.BodyDeclaration;

import java.util.LinkedList;
import java.util.List;

public class EnumBodyDeclarationsContextAdapter implements Adapter<List<BodyDeclaration>, Java7Parser.EnumBodyDeclarationsContext> {
    public List<BodyDeclaration> adapt(Java7Parser.EnumBodyDeclarationsContext context) {

/*
        enumBodyDeclarations
        :   SEMI
                (classBodyDeclaration
                )*
        ;
  */

        if (context.classBodyDeclaration() == null || context.classBodyDeclaration().size() == 0) {
            return null;
        }

        List<BodyDeclaration> bodyDeclarationList = new LinkedList<BodyDeclaration>();
        for (Java7Parser.ClassBodyDeclarationContext classBodyDeclarationContext : context.classBodyDeclaration()) {
            bodyDeclarationList.add(Adapters.getClassBodyDeclarationContextAdapter().adapt(classBodyDeclarationContext));
        }

        return bodyDeclarationList;
    }
}

==> antlr-java-parser-1.0.11-sources.jar: com/github/antlrjavaparser/adapter/EnumBodyDeclarationsContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.body.BodyDeclaration;

import java.util.LinkedList;
import java.util.List;

public class EnumBodyDeclarationsContextAdapter implements Adapter<List<BodyDeclaration>, Java7Parser.EnumBodyDeclarationsContext> {
    public List<BodyDeclaration> adapt(Java7Parser.EnumBodyDeclarationsContext context, AdapterParameters adapterParameters) {

/*
        enumBodyDeclarations
        :   SEMI
                (classBodyDeclaration
                )*
        ;
  */

        if (context.classBodyDeclaration() == null || context.classBodyDeclaration().size() == 0) {
            return null;
        }

        List<BodyDeclaration> bodyDeclarationList = new LinkedList<BodyDeclaration>();
        for (Java7Parser.ClassBodyDeclarationContext classBodyDeclarationContext : context.classBodyDeclaration()) {
            bodyDeclarationList.add(Adapters.getClassBodyDeclarationContextAdapter().adapt(classBodyDeclarationContext, adapterParameters));
        }

        return bodyDeclarationList;
    }
}
